``fsl``
=======

.. toctree::
   :hidden:

   fsl.data
   fsl.scripts
   fsl.utils
   fsl.transform
   fsl.version
   fsl.wrappers

.. automodule:: fsl
    :members:
    :undoc-members:
    :show-inheritance:
